@@ -13,6 +13,8 @@ from irisml.core import JobDescription
 
 logger = logging.getLogger(__name__)
 
+SHARED_MEMORY_SIZE = '8g'
+
 
 class AMLJobManager:
     def __init__(self, subscription_id, workspace_name, experiment_name, compute_target_name, use_sp_on_remote=False, cache_url=None):
@@ -86,7 +88,7 @@ class AMLJobManager:
 
         script_run_config = azureml.core.ScriptRunConfig(source_directory=project_dir, compute_target=self._get_compute_target(), environment=self._get_environment(job_env), command=command)
         script_run_config.run_config.environment_variables.update(environment_variables)
-        script_run_config.run_config.docker.shm_size = '4g'  # PyTorch's DataLoader requires shared memory for storing tensors.
+        script_run_config.run_config.docker.shm_size = SHARED_MEMORY_SIZE  # PyTorch's DataLoader requires shared memory for storing tensors.
         return script_run_config
 
     def submit(self, job, job_env):
